import requests
from ping.helper.apiHelper import json_deserialize, check_errors


def initiate(headers, base_url, payment_object, payment_order_id):
    #Does a POST request to '/api/v1/payment_orders/{payment_order_id}/payments.

    #Initiates a payment for a payment order.
    #Args (provided by the tenant):
    #  payment_object (object, required): An object containing all information needed to initiate a payment
    #  payment_order_id (string, required): An ID of a specific Payment Order
    #Returns:
    #  Response: A json object with the response value as well as other
    #  useful information such as status codes, headers and a potention error.


    # Prepare and execute response
    _path = f'/api/v1/payment_orders/{payment_order_id}/payments'
    _url = base_url + _path
    response = requests.post(_url, headers=headers, json=payment_object)

    # deserialize and check errors
    decoded = json_deserialize(response.text)
    _result = check_errors(response, decoded)
    return _result


def get(headers, base_url, payment_order_id, payment_id):
    #Does a GET request to /api/v1/payment_orders/{payment_order_id}/payments/{payment_id}.

    #Retrieves a payment from a payment order
    #Args (provided by the tenant):
    #  payment_order_id (string, required): A string cointaining the ID of a specific payment order
    #  payment_id (string, required): A string cointaining the ID of a specific payment
    #Returns:
    #  Response: A json object with the response value as well as other
    #  useful information such as status codes, headers and a potention error.
    

    # Prepare and execute response
    _path = f'/api/v1/payment_orders/{payment_order_id}/payments/{payment_id}'
    _url = base_url + _path
    response = requests.get(_url, headers=headers)

    # deserialize and check errors
    decoded = json_deserialize(response.text)
    _result = check_errors(response, decoded)
    return _result



from cgi import test
import unittest
from ping.api_resources import payments_api
from ping.payments_api import PaymentsApi
import os
from dotenv import load_dotenv

class testHelper(unittest.TestCase):
    load_dotenv()
    def run_tests(self, response, status = 200):
        self.assertIsNotNone(response)
        if status > 204:
            self.assertEqual(response.status_code, status)
            self.assertFalse(response.is_success())
            self.assertTrue(response.is_error())
            self.assertIsNotNone(response.body)
        else:
            self.assertEqual(response.status_code, status)
            self.assertFalse(response.is_error())
            self.assertTrue(response.is_success())
            self.assertIsNotNone(response.body)
            self.assertIsNone(response.errors)


    def api_is_connected():
        payments_api = PaymentsApi(os.getenv("TENANT_ID"))
        ping = payments_api.ping.ping_the_api()
        return True if ping.body == "pong" else False

        #creates a payment order and a payment to that order that now is ready to get closed, split and settled
    def prepare_payment_order_handling():
        payments_api = PaymentsApi(os.getenv("TENANT_ID"))
        payment_order = payments_api.paymentOrder.create(os.getenv("SPLIT_TREE_ID"), "SEK")
        payment_order_id = payment_order.body["id"]
        payments_api.payment.initiate(testHelper.get_payment_body(), payment_order_id)

        return payment_order_id

    def get_payment_body():
        dummy_body = {
            "currency": "SEK",
            "metadata": {
                "delivery_id": "368745"
                },
            "method": "dummy",
            "order_items": [
                {
                    "amount": 2500,
                    "merchant_id": os.getenv("MERCHANT_ID"),
                    "name": "Delivery, Marios Pasta (Pasta La Vista)",
                    "vat_rate": 12
                },
            ],
            "provider": "dummy",
            "provider_method_parameters": {
                "desired_payment_status": "COMPLETED"
            },
            "total_amount": 2500
        }
        return dummy_body



import requests
from ping.helper.apiHelper import json_deserialize, check_errors


def list(headers, base_url):
    #Does a GET request to /api/v1/merchants.

    #Lists merchants associated with a tenant. The merchant details
    #include email, id, name, organization number and phone number.

    #Args:
    #    None arguments.
    #Returns:
    #    Response: A json object with the response value as well as other
    #    useful information such as status codes, headers and a potention error.
    

    # Prepare and execute response
    _path = '/api/v1/merchants'
    _url = base_url + _path
    response = requests.get(_url, headers=headers)

    # deserialize and check errors
    decoded = json_deserialize(response.text)
    _result = check_errors(response, decoded)
    return _result


def create(headers, base_url, merchant_object):
    # Does a POST request to /api/v1/merchants.

    # Creates a new merchants for a tenant.
    # You must provide a object with the following values:
    # - "name"
    # - "organization_number"
    # Args(provided by the tenant):
    #   merchant_object (object, required): An object containing required merchant data.
    # Returns:
    #    Response: A json object with the response value as well as other
    #    useful information such as status codes, headers and a potention error.
    

    # Prepare and execute response
    _path = '/api/v1/merchants'
    _url = base_url + _path
    response = requests.post(_url, headers=headers, json=merchant_object)

    # deserialize and check errors
    decoded = json_deserialize(response.text)
    _result = check_errors(response, decoded)
    return _result


def get(headers, base_url, merchant_id):
    # Does a GET request to /api/v1/merchants/{merchant_id}.

    # Provides details for a single merchant. The details include email, id,
    #name, organization name, organization number, phone number and status.

    # Args:
    #    merchant_id (string, required). The ID of the of the merchant to retrive.
    # Returns:
    #    Response: A json object with the response value as well as other
    #    useful information such as status codes, headers and a potention error.
    

    # Prepare and execute response
    _path = f'/api/v1/merchants/{merchant_id}'
    _url = base_url + _path
    response = requests.get(_url, headers=headers)

    # Deserialize and check errors
    decoded = json_deserialize(response.text)
    _result = check_errors(response, decoded)
    return _result



import requests
from ping.helper.apiHelper import json_deserialize, check_errors


def list(headers, base_url, date_from, date_to):
    #Does a GET request to /api/v1/payment_orders.

    #Retrieves a list of payouts.
    #Args (provided by the tenant):
    #  date_from (string, optional): The timestamp for the beginning of
    #    the reporting period, in RFC 3339 format. Default: None
    #  date_to (string, optional): The timestamp for the end of
    #    the reporting period, RFC 3339 format. Default: None
    #Returns:
    #  Response: A json object with the response value as well as other
    #  useful information such as status codes, headers and a potention error.
    

    _path = '/api/v1/payouts'

    # checks for possible query parameters
    if date_from and date_to is None:
        _path = _path + f'?from={date_from}'
    elif date_to and date_from is None:
        _path = _path + f'?to={date_to}'
    elif date_from and date_to:
        _path = _path + f'?from={date_from}&to={date_to}'

    _url = base_url + _path
    response = requests.get(_url, headers=headers)

    # deserialize and check errors
    decoded = json_deserialize(response.text)
    _result = check_errors(response, decoded)
    return _result

def get(headers, base_url, payout_id):
    # Does a GET request to /api/v1/payouts/{payout_id}.

    # Retrives a specific payout.
    # Args (provided by the tenant):
    #    payout_id (String, required): The ID of the of the payout to retrive.
    # Returns:
    #    Response: A json object with the response value as well as other
    #  useful information such as status codes, headers and a potention error.

    # Prepare and execute response
    _path = f'/api/v1/payouts/{payout_id}'
    _url = base_url + _path
    response = requests.get(_url, headers=headers)

    # deserialize and check errors
    decoded = json_deserialize(response.text)
    _result = check_errors(response, decoded)
    return _result


import requests
from ping.helper.apiHelper import json_deserialize, check_errors


def list(headers, base_url, date_from, date_to):
    #Does a GET request to /api/v1/payment_orders.

    #Retrieves a list of payment orders.
    #Args (provided by the tenant):
    #  date_from (string, optional): The timestamp for the beginning of
    #    the reporting period, in RFC 3339 format. Default: None
    #  date_to (string, optional): The timestamp for the end of
    #    the reporting period, RFC 3339 format. Default: None
    #Returns:
    #  Response: A json object with the response value as well as other
    #  useful information such as status codes, headers and a potention error.
    

    _path = '/api/v1/payment_orders'

    # checks for possible query parameters
    if date_from and date_to is None:
        _path = _path + f'?from={date_from}'
    elif date_to and date_from is None:
        _path = _path + f'?to={date_to}'
    elif date_from and date_to:
        _path = _path + f'?from={date_from}&to={date_to}'

    _url = base_url + _path
    response = requests.get(_url, headers=headers)

    # deserialize and check errors
    decoded = json_deserialize(response.text)
    _result = check_errors(response, decoded)
    return _result


def create(headers, base_url, split_tree_id, currency):
    # Does a POST request to /api/v1/payment_orders.

    # Creates a new payment order.
    # Args (provided by the tenant):
    #    split_tree_id (string, required): An string with a valid split tree ID.
    # Returns:
    #    Response: A json object with the response value as well as other
    #    useful information such as status codes, headers and a potention error.
    

    # Prepare and execute response
    _path = '/api/v1/payment_orders'
    _url = base_url + _path
    _payload = {
        "split_tree_id": split_tree_id,
        "currency": currency
    }
    response = requests.post(_url, headers=headers, json=_payload)

    # deserialize and check errors
    decoded = json_deserialize(response.text)
    _result = check_errors(response, decoded)
    return _result


def get(headers, base_url, payment_order_id):
    # Does a GET request to /api/v1/payment_orders/{payment_order_id}.

    # Retrives a specific payment order.
    # Args (provided by the tenant):
    #    payment_order_id (String, required): The ID of the of the payment order to retrive.
    # Returns:
    #    Response: A json object with the response value as well as other
    

    # Prepare and execute response
    _path = f'/api/v1/payment_orders/{payment_order_id}'
    _url = base_url + _path
    response = requests.get(_url, headers=headers)

    # deserialize and check errors
    decoded = json_deserialize(response.text)
    _result = check_errors(response, decoded)
    return _result


def update(headers, base_url, payment_order_id, split_tree_id):
    # Does a PUT request to /api/v1/payment_orders/{payment_order_id}.

    # Updates the split tree of a specific payment order.
    # Args (provided by the tenant):
    #    payment_order_id (String, required): The ID of the of the payment order to update.
    #    split_tree_id (String, required): An string with a valid split tree ID.
    # Response: A json object with the response value as well as other
    #    useful information such as status codes, headers and a potention error.
    

    # Prepare and execute response
    _path = f'/api/v1/payment_orders/{payment_order_id}'
    _url = base_url + _path
    _payload = {
        "split_tree_id": split_tree_id
    }
    response = requests.put(_url, headers=headers, json=_payload)

    # deserialize and check errors
    decoded = json_deserialize(response.text)
    _result = check_errors(response, decoded)
    return _result


def close(headers, base_url, payment_order_id):
    # Does a PUT request to /api/v1/payment_orders/{payment_order_id}/close'.

    # Closes a specific payment order.
    # Args (provided by the tenant):
    #    payment_order_id (String, required): The ID of the of the payment order to close.
    # Returns:
    #    Response: A json object with the response value as well as other
    #    useful information such as status codes, headers and a potention error.
    

    # Prepare and execute response
    _path = f'/api/v1/payment_orders/{payment_order_id}/close'
    _url = base_url + _path
    response = requests.put(_url, headers=headers)

    # deserialize and check errors
    decoded = json_deserialize(response.text)
    _result = check_errors(response, decoded)
    return _result

def split(headers, base_url, payment_order_id, fast_forward):
    # Does a PUT request to /api/v1/payment_orders/{payment_order_id}/split.

    # Split a specific payment order.
    # Args (provided by the tenant):
    #    payment_order_id (String, required): The ID of the of the payment order to split.
    # Returns:
    #    Response: A json object with the response value as well as other
    #    useful information such as status codes, headers and a potention error.
    

    # Prepare and execute response
    _path = f'/api/v1/payment_orders/{payment_order_id}/split'
    _url = base_url + _path

    if fast_forward == True:
        _payload = {
            "fast_forward": fast_forward
        }
        response = requests.put(_url, headers=headers, json=_payload)
    else:
        response = requests.put(_url, headers=headers)

    # deserialize and check errors
    decoded = json_deserialize(response.text)
    _result = check_errors(response, decoded)
    return _result


def settle(headers, base_url, payment_order_id, fast_forward):
    # Does a PUT request to /api/v1/payment_orders/{payment_order_id}/settle'.

    # Settle a specific payment order.
    # Args (provided by the tenant):
    #    payment_order_id (String, required): The ID of the of the payment order to settle.
    # Returns:
    #    Response: A json object with the response value as well as other
    #    useful information such as status codes, headers and a potention error.
    

    # Prepare and execute response
    _path = f'/api/v1/payment_orders/{payment_order_id}/settle'
    _url = base_url + _path
    
    if fast_forward == True:
        _payload = {
            "fast_forward": fast_forward
        }
        response = requests.put(_url, headers=headers, json=_payload)
    else:
        response = requests.put(_url, headers=headers)

    # deserialize and check errors
    decoded = json_deserialize(response.text)
    _result = check_errors(response, decoded)
    return _result



import requests
from ping.helper.apiHelper import json_deserialize, check_errors


def ping_the_api(headers, base_url):
    #Does a GET request to /api/v1/ping.

    #Ping the API to verify that it is reachable

    #Args:
    #    None arguments.
    #Returns:
    #    Response: returns "Pong" if the API is reachable
    

    # Prepare and execute response
    _path = '/api/v1/ping'
    _url = base_url + _path
    response = requests.get(_url, headers=headers)

    # deserialize and check errors
    decoded = json_deserialize(response.text)
    _result = check_errors(response, decoded)
    return _result


import unittest
import uuid
import os
from dotenv import load_dotenv
from ping.payments_api import PaymentsApi
from test_helper import testHelper


@unittest.skipUnless(testHelper.api_is_connected(), "A connection to the API is needed")
class TestPayment(unittest.TestCase):

    @classmethod
    def setUpClass(cls):
        load_dotenv()
        cls.test_helper = testHelper
        cls.payment_order_id = os.getenv("PAYMENT_ORDER_ID_OPEN")
        cls.payments_api = PaymentsApi(os.getenv("TENANT_ID"))
        cls.dummy_body = cls.test_helper.get_payment_body()

# Get Payments Tests
    # gets payment correctly
    def test_get_payment_200(self):
        payment_id = os.getenv("PAYMENT_ID")

        response = self.payments_api.payment.get(self.payment_order_id, payment_id)
        self.test_helper.run_tests(self, response, 200)

    # gets payment with an incorrect id
    def test_get_payment_404(self):
        payment_id = ""

        response = self.payments_api.payment.get(self.payment_order_id, payment_id)
        self.test_helper.run_tests(self, response, 404)

# Initiate Payment Tests
    # Initiate a correct payment (status code 200)
    def test_initiate_payment_200(self):
        response = self.payments_api.payment.initiate(self.dummy_body, self.payment_order_id)
        self.test_helper.run_tests(self, response)

    # Initiate a payment with incorrect values inside payment object (status code 422)
    def test_initiate_payment_422(self):
        payment_order_id = 0
        self.dummy_body["method"] = 0

        response = self.payments_api.payment.initiate(self.dummy_body, payment_order_id)
        self.test_helper.run_tests(self, response, 422)

    # Initiate a payment on a non-existing payment order (status code 404)
    def test_initiate_payment_404(self):
        error_payment_order_id = uuid.uuid4()

        response = self.payments_api.payment.initiate(self.dummy_body, error_payment_order_id)
        self.test_helper.run_tests(self, response, 404)


if __name__ == '__main__':
    unittest.main()



import unittest
import uuid
import os
from dotenv import load_dotenv
from ping.payments_api import PaymentsApi
from test_helper import testHelper


@unittest.skipUnless(testHelper.api_is_connected(), "A connection to the API is needed")
class TestPaymentOrder(unittest.TestCase):

    @classmethod
    def setUpClass(cls):
        load_dotenv()
        cls.payments_api = PaymentsApi(os.getenv("TENANT_ID"))
        cls.split_tree_id = os.getenv("SPLIT_TREE_ID")
        cls.test_helper = testHelper

    def setUp(self):
        self.payment_order_id = os.getenv("PAYMENT_ORDER_ID")

# Get Payment Orders Tests
    # get payment orders correctly (status code 200)
    def test_list_200(self): 
    
        response_date = self.payments_api.paymentOrder.list("2020-03-27T09:42:30Z", "2022-03-27T09:42:30Z")
        response = self.payments_api.paymentOrder.list()

        # tests with start-end date
        self.test_helper.run_tests(self, response_date)

        # tests without date
        self.test_helper.run_tests(self, response)

    # get payment orders with impossible dates (status code 422)
    def test_list_422(self):
        response_date = self.payments_api.paymentOrder.list("12/90/2019", "40/10/2020")
        self.test_helper.run_tests(self, response_date, 422)

# Create Payment Order Tests
    # creates a payment order correctly (status code 200)
    def test_create_200(self):
        response = self.payments_api.paymentOrder.create(self.split_tree_id, "SEK")
        self.test_helper.run_tests(self, response)

    # creates a payment orders with incorrect id format (status code 422)
    def test_create_422(self):
        response = self.payments_api.paymentOrder.create(self.split_tree_id, "")
        self.test_helper.run_tests(self, response, 422)

# Get Payment Order Tests
    # gets a payment order correctly (status code 200)
    def test_get_200(self):
        response = self.payments_api.paymentOrder.get(self.payment_order_id)
        self.test_helper.run_tests(self, response)
    
    # get a payment order with incorrect id format (status code 422)
    def test_get_422(self):
        response = self.payments_api.paymentOrder.get(0)
        self.test_helper.run_tests(self, response, 422)
    
    # get a payment order with a non-existing id (status code 404)
    def test_get_404(self):
        response = self.payments_api.paymentOrder.get(uuid.uuid4())
        self.test_helper.run_tests(self, response, 404)

# Update Payment Order Tests
    # updates a payment order correctly (status code 204)
    def test_update_204(self):
        
        response = self.payments_api.paymentOrder.update(
            os.getenv("PAYMENT_ORDER_ID_OPEN"),
            self.split_tree_id
        )
        self.test_helper.run_tests(self, response, 204)
        

    # updates a payment order with incorrect id format (status code 422)
    def test_update_422(self):
        
        response = self.payments_api.paymentOrder.update(
            0,
            self.split_tree_id
        )
        self.test_helper.run_tests(self, response, 422)
        

    # updates a payment order with a non-existing id (status code 404)
    def test_update_404(self):
        
        response = self.payments_api.paymentOrder.update(
            "",
            self.split_tree_id
        )
        self.test_helper.run_tests(self, response, 404)
        

# Close Payment Order Tests
    # closes a payment order correctly (status code 204)
    def test_close_204(self):
        response = self.payments_api.paymentOrder.close(self.payment_order_id)
        self.test_helper.run_tests(self, response, 204)

    # closes a payment order with an incorrect id format (status code 422)
    def test_close_422(self):
        response = self.payments_api.paymentOrder.close(0)
        self.test_helper.run_tests(self, response, 422)

    # closes a payment order with a non-existing id (status code 404)
    def test_close_404(self):
        response = self.payments_api.paymentOrder.close(uuid.uuid4())
        self.test_helper.run_tests(self, response, 404)

# Split Payment Order Tests
    # splits a payment order correctly (status code 204)
    def test_split_204(self):
        response = self.payments_api.paymentOrder.split(self.payment_order_id)
        self.test_helper.run_tests(self, response, 204)

    # fast forwards and splits a payment order correctly (status code 204)
    def test_split_fast_forward_204(self):
        payment_order_id = self.test_helper.prepare_payment_order_handling()
        response = self.payments_api.paymentOrder.split(payment_order_id, fast_forward=True)
        self.test_helper.run_tests(self, response, 204)

    # splits a payment order with an incorrect id format (status code 422)
    def test_split_422(self):
        response = self.payments_api.paymentOrder.split(0)
        self.test_helper.run_tests(self, response, 422)

    # splits a payment order with a non-existing id (status code 404)
    def test_split_404(self):
        response = self.payments_api.paymentOrder.split(uuid.uuid4())
        self.test_helper.run_tests(self, response, 404)

# Settle Payment Order Tests
    # settles a payment correctly (status code 204)
    def  test_settle_204(self):
        response = self.payments_api.paymentOrder.settle(self.payment_order_id)
        self.test_helper.run_tests(self, response, 204)
    
    # fast forwards and settles a payment correctly (status code 204)
    def  test_settle_order_fast_forward_204(self):
        payment_order_id = self.test_helper.prepare_payment_order_handling()
        response = self.payments_api.paymentOrder.settle(payment_order_id, fast_forward=True)
        self.test_helper.run_tests(self, response, 204)

    # settles a payment with an incorrect id format (status code 422)
    def  test_settle_422(self):
        response = self.payments_api.paymentOrder.settle(0)
        self.test_helper.run_tests(self, response, 422)

    # settles a payment with a non-existing id (status code 404)
    def  test_settle_404(self):
        response = self.payments_api.paymentOrder.settle(uuid.uuid4())
        self.test_helper.run_tests(self, response, 404)


if __name__ == '__main__':
    unittest.main()



from ping.api_resources.payments_api import merchants
from ping.api_resources.payments_api import paymentOrders
from ping.api_resources.payments_api import payments
from ping.api_resources.payments_api import payouts
from ping.api_resources.payments_api import pings
from ping.helper.apiHelper import get_base_url


class PaymentsApi:
    # A controller to access all endpoints in the API.
    def __init__(self, tenant_id="", environment="sandbox"):
        self.tenant_id = tenant_id
        self.environment = environment
        self.base_url = get_base_url(environment)
        self.headers = {
            "Accept": "application/json",
            "tenant_id": tenant_id
            }

    @property
    def merchant(self):
        return Merchant(self.headers, self.base_url)

    @property
    def paymentOrder(self):
        return PaymentOrder(self.headers, self.base_url)

    @property
    def payment(self):
        return Payment(self.headers, self.base_url)
    
    @property
    def payout(self):
        return Payout(self.headers, self.base_url)

    @property
    def ping(self):
        return Ping(self.headers, self.base_url)



class BaseEndpoints:
    # Endpoint classes inherit from this base class
    def __init__(self, headers, base_url):
        self.headers = headers
        self.base_url = base_url


class Merchant(BaseEndpoints):
    # Endpoint class for merchant endpoints
    def list(self):
        return merchants.list(self.headers, self.base_url)

    def create(self, obj):
        return merchants.create(self.headers, self.base_url, obj)

    def get(self, merchant_id):
        return merchants.get(self.headers, self.base_url, merchant_id)


class PaymentOrder(BaseEndpoints):
    # Endpoint class for payment order endpoints
    def list(self, date_from=None, date_to=None):
        return paymentOrders.list(self.headers, self.base_url, date_from, date_to)

    def create(self, split_tree_id, currency):
        return paymentOrders.create(self.headers, self.base_url, split_tree_id, currency)

    def get(self, payment_order_id):
        return paymentOrders.get(self.headers, self.base_url, payment_order_id)

    def update(self, payment_order_id, split_tree_id):
        return paymentOrders.update(self.headers, self.base_url, payment_order_id, split_tree_id)

    def close(self, payment_order_id):
        return paymentOrders.close(self.headers, self.base_url, payment_order_id)

    def split(self, payment_order_id, fast_forward = False):
        return paymentOrders.split(self.headers, self.base_url, payment_order_id, fast_forward)

    def settle(self, payment_order_id, fast_forward = False):
        return paymentOrders.settle(self.headers, self.base_url, payment_order_id, fast_forward)


class Payment(BaseEndpoints):
    # Endpoint class for payment endpoints
    def initiate(self, obj, payment_order_id):
        return payments.initiate(self.headers, self.base_url, obj, payment_order_id)

    def get(self, payment_order_id, payment_id):
        return payments.get(self.headers, self.base_url, payment_order_id, payment_id)


class Payout(BaseEndpoints):
    # Endpoint class for payout endpoints
    def list(self, date_from=None, date_to=None):
        return payouts.list(self.headers, self.base_url, date_from, date_to)
    
    def get(self, payout_id):
        return payouts.get(self.headers, self.base_url, payout_id)


class Ping(BaseEndpoints):
    # Endpoint class for ping endpoints
    def ping_the_api(self):
        return pings.ping_the_api(self.headers, self.base_url)



import jsonpickle
from ping.helper.apiResponse import ApiResponse


def json_deserialize(json, unboxing_function=None, as_dict=False):
    # JSON Deserialization of a given string.
    # Args:
    #    json (str): The JSON serialized string to deserialize.
    # Returns:
    #    dict: A dictionary representing the data contained in the
    #        JSON serialized string.
    
    if json is None:
        return None

    try:
        decoded = jsonpickle.decode(json)
    except ValueError:
        return json

    if unboxing_function is None:
        return decoded

    if as_dict:
        return {k: unboxing_function(v) for k, v in decoded.items()}
    elif isinstance(decoded, list):
        return [unboxing_function(element) for element in decoded]
    else:
        return unboxing_function(decoded)


def check_errors(response, decoded):
    if type(decoded) is dict:
        errors = decoded.get('errors')
    else:
        errors = None
    result = ApiResponse(response, body=decoded, errors=errors)
    return result


def get_base_url(environment):

    if environment == "sandbox":
        return "http://sandbox.pingpayments.com/payments"
    elif environment == "production":
        return "http://pingpayments.com/payments"





class ApiResponse:

    # Http response received.
    # Attributes:
    #    status_code (int): The status code response from the server that
    #        corresponds to this response.
    #    reason_phrase (string): The reason phrase returned by the server.
    #    headers (dict): A dictionary of headers (key : value) that were
    #        returned with the response
    #    text (string): The Raw body of the HTTP Response as a string
    #    request (HttpRequest): The request that resulted in this response.
    #    body (Object): The data field specified for the response
    #    errors (Array<String>): Any errors returned by the server
    

    def __init__(self, http_response,
                 body=None,
                 errors=None):

        # The Constructor
        # Args:
        #    http_response (HttpResponse): The original, raw response from the api
        #    data (Object): The data field specified for the response
        #    errors (Array<String>): Any errors returned by the server
        

        self.status_code = http_response.status_code
        self.headers = http_response.headers
        self.text = http_response.text
        self.request = http_response.request
        self.body = body
        self.errors = errors
        if type(body) is dict:
            self.cursor = body.get('cursor')

    def is_success(self):
        # Returns true if status code is between 200-300
        
        return 200 <= self.status_code < 300

    def is_error(self):
        # Returns true if status code is between 400-600
        
        return 400 <= self.status_code < 600

    def __repr__(self):
        return '<ApiResponse [%s]>' % (self.text)



from setuptools import setup, find_packages


with open('README.md', 'r', encoding='utf-8') as fh:
    long_description = fh.read()

setup(
    name='ping-sdk',
    version='4.0.0',
    description='Use this Python library to manage Ping Payments API regarding merchants, payment orders, payments and payouts',
    long_description=long_description,
    long_description_content_type="text/markdown",
    author='Ping Payments',
    author_email='tech@pingpayments.com',
    url='https://www.pingpayments.com/',
    license='MIT',
    packages=find_packages(),
    zip_safe=False,
    install_requires=[
        'jsonpickle~=1.4, >= 1.4.1',
        'requests~=2.25',
        'python-dotenv~=0.20.0',
    ],
    tests_require=[
        'flake8>=3.9',
        'tox>=3.24'
    ],
    classifiers=[
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: Implementation :: PyPy',
        'Topic :: Software Development :: Libraries :: Python Modules'],
)



import os
import unittest
import uuid
from dotenv import load_dotenv
from ping.payments_api import PaymentsApi
from test_helper import testHelper


@unittest.skipUnless(testHelper.api_is_connected(), "A connection to the API is needed")
class TestMerchant(unittest.TestCase):

    @classmethod
    def setUpClass(cls):
        load_dotenv()

        cls.payments_api = PaymentsApi(os.getenv("TENANT_ID"))
        cls.test_helper = testHelper

# Get Merchants Tests
    # gets merchants successfully
    def test_list_200(self):
        response = self.payments_api.merchant.list()
        self.test_helper.run_tests(self, response)

# Create New Merchant Tests
    # creates a merchant correctly (status code 200)
    def test_create_200(self):
        response = self.payments_api.merchant.create(
            {
                "name": "Company inc",
                "organization": {
                    "country": "SE",
                    "se_organization_number": "5555555555"
                }
            }
        )
        self.test_helper.run_tests(self, response)
    
    # creates a merchant with incorrect values inside merchant object (status code 422)
    def test_create_422(self):
        response = self.payments_api.merchant.create({})
        self.test_helper.run_tests(self, response, 422)

# Get Specific Merchant Tests
    # get a specific merchant correctly (status code 200)
    def test_get_200(self):
        response = self.payments_api.merchant.get(os.getenv("MERCHANT_ID"))
        self.test_helper.run_tests(self, response)

    # get a specific merchant with wrong id format (status code 422)
    def test_get_422(self):
        response = self.payments_api.merchant.get(0)
        self.test_helper.run_tests(self, response, 422)
    
    # get a specific merchant with a non-existing id (status code 404)
    def test_get_404(self):
        response = self.payments_api.merchant.get(uuid.uuid4())
        self.test_helper.run_tests(self, response, 404)


if __name__ == '__main__':
    unittest.main()
